@@ -95,7 +95,7 @@ rainette2_explor <- function(res, dtm = NULL, corpus_src = NULL) {
           miniTabPanel(
         "Cluster documents", icon = shiny::icon("file-text"),
         miniContentPanel(
-          docs_sample_ui("rainette2")
+          docs_sample_ui("rainette2", res)
         )
       ) 
     )
